@@ -48,7 +48,8 @@ AdaBagModel <- function(mfinal = 100, minsplit = 20,
     name = "AdaBagModel",
     label = "Bagging with Classification Trees",
     packages = "adabag",
-    types = "factor",
+    response_types = "factor",
+    predictor_encoding = "terms",
     params = params,
     grid = function(x, length, ...) {
       list(
@@ -56,7 +57,6 @@ AdaBagModel <- function(mfinal = 100, minsplit = 20,
         maxdepth = 1:min(length, 30)
       )
     },
-    design = "terms",
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
       adabag::bagging(formula, data = as.data.frame(data), ...)
