@@ -72,9 +72,9 @@ BARTModel <- function(K = NULL, sparse = FALSE, theta = 0, omega = 1,
     name = "BARTModel",
     label = "Bayesian Additive Regression Trees",
     packages = "BART",
-    types = c("factor", "numeric", "Surv"),
+    response_types = c("factor", "numeric", "Surv"),
+    predictor_encoding = "model.matrix",
     params = params(environment()),
-    design = "model.matrix",
     fit = function(formula, data, weights, K = NULL, sigest = NA, sigdf = 3,
                    sigquant = 0.90, lambda = NA, ...) {
       x <- model.matrix(data, intercept = FALSE)
