@@ -73,7 +73,8 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
     name = "BlackBoostModel",
     label = "Gradient Boosting with Regression Trees",
     packages = c("mboost", "partykit"),
-    types = c("binary", "numeric", "Surv"),
+    response_types = c("binary", "numeric", "Surv"),
+    predictor_encoding = "terms",
     params = params,
     grid = function(x, length, ...) {
       list(
@@ -81,7 +82,6 @@ BlackBoostModel <- function(family = NULL, mstop = 100, nu = 0.1,
         maxdepth = 1:min(length, 10)
       )
     },
-    design = "terms",
     fit = function(formula, data, weights, family = NULL, ...) {
       if (is.null(family)) {
         family <- switch_class(response(data),
