@@ -40,21 +40,21 @@ KNNModel <- function(k = 7, distance = 2, scale = TRUE,
     name = "KNNModel",
     label = "K-Nearest Neighbors Model",
     packages = "kknn",
-    types = c("factor", "numeric", "ordered"),
+    response_types = c("factor", "numeric", "ordered"),
+    predictor_encoding = "model.matrix",
     params = params(environment()),
     grid = function(x, length, random, ...) {
       params <- list(
         k = round(seq_range(0, 5, c(1, nrow(x) / 3), length + 1))
       )
       if (random) {
-        params$distance <- seq(0, 3, length = length)
+        params$distance <- seq_inner(0, 4, length = length)
         params$kernel <- c("optimal", "biweight", "cos", "epanechnikov",
                            "gaussian", "inv", "rank", "rectangular",
                            "triangular", "triweight")
       }
       params
     },
-    design = "model.matrix",
     fit = function(formula, data, weights, ...) {
       assert_equal_weights(weights)
       list(formula = formula, train = as.data.frame(data), ...)
