@@ -41,7 +41,8 @@ RPartModel <- function(minsplit = 20, minbucket = round(minsplit / 3),
     name = "RPartModel",
     label = "Recursive Partitioning and Regression Trees",
     packages = c("rpart", "partykit"),
-    types = c("factor", "numeric", "Surv"),
+    response_types = c("factor", "numeric", "Surv"),
+    predictor_encoding = "terms",
     params = list(control = as.call(c(.(list), params(environment())))),
     grid = function(x, length, ...) {
       cptable <- fit(x, model = RPartModel(cp = 0))$cptable[, "CP"]
@@ -49,7 +50,6 @@ RPartModel <- function(minsplit = 20, minbucket = round(minsplit / 3),
         cp = seq(min(cptable), max(cptable), length = length)
       )
     },
-    design = "terms",
     fit = function(formula, data, weights, ...) {
       method <- switch_class(response(data),
                              "factor" = "class",
